package ovh.corail.tombstone.helper;

import java.time.LocalDate;
import java.time.temporal.ChronoField;
import java.util.Locale;
import java.util.function.Function;
import java.util.function.Predicate;
import java.util.stream.IntStream;
import net.minecraft.util.Mth;
import net.minecraft.world.entity.Entity;
import net.minecraft.world.level.Level;
import net.neoforged.api.distmarker.Dist;
import net.neoforged.api.distmarker.OnlyIn;

/* loaded from: TimeHelper.class */
public final class TimeHelper {
    public static long SERVER_START_TIME;
    private static SpecialEvent SPECIAL_EVENT = SpecialEvent.NONE;
    private static final String[] UNITY = {"d", "h", "m", "s"};

    public static void init() {
        SERVER_START_TIME = systemTime();
        LocalDate date = LocalDate.now();
        if (date.get(ChronoField.MONTH_OF_YEAR) == 4 && date.get(ChronoField.DAY_OF_MONTH) == 1) {
            SPECIAL_EVENT = SpecialEvent.APRIL_FOOLS;
            return;
        }
        if ((date.get(ChronoField.MONTH_OF_YEAR) == 10 && date.get(ChronoField.DAY_OF_MONTH) >= 20) || (date.get(ChronoField.MONTH_OF_YEAR) == 11 && date.get(ChronoField.DAY_OF_MONTH) <= 3)) {
            SPECIAL_EVENT = SpecialEvent.HALLOWEEN;
            return;
        }
        if (date.get(ChronoField.MONTH_OF_YEAR) == 12 && date.get(ChronoField.DAY_OF_MONTH) >= 6) {
            SPECIAL_EVENT = SpecialEvent.CHRISTMAS;
        } else if ((date.get(ChronoField.MONTH_OF_YEAR) == 3 && date.get(ChronoField.DAY_OF_MONTH) >= 21) || (date.get(ChronoField.MONTH_OF_YEAR) == 4 && date.get(ChronoField.DAY_OF_MONTH) <= 21)) {
            SPECIAL_EVENT = SpecialEvent.EASTER;
        }
    }

    public static long systemTime() {
        return System.currentTimeMillis();
    }

    public static SpecialEvent getSpecialEvent() {
        return SPECIAL_EVENT;
    }

    @OnlyIn(Dist.CLIENT)
    public static void setSpecialEvent(SpecialEvent event) {
        SPECIAL_EVENT = event;
    }

    public static boolean isAprilFoolsDay() {
        return SPECIAL_EVENT == SpecialEvent.APRIL_FOOLS;
    }

    public static boolean isDateAroundHalloween() {
        return SPECIAL_EVENT == SpecialEvent.HALLOWEEN;
    }

    public static boolean isDateAroundChristmas() {
        return SPECIAL_EVENT == SpecialEvent.CHRISTMAS;
    }

    public static boolean isDateAroundEaster() {
        return SPECIAL_EVENT == SpecialEvent.EASTER;
    }

    public static long worldTicks(Level level) {
        return level.getGameTime();
    }

    public static int tickFromSecond(int second) {
        return second * 20;
    }

    public static int tickFromMinute(int minute) {
        return minute * 1200;
    }

    public static int tickFromHour(int hour) {
        return hour * 72000;
    }

    public static int tickFromDay(int day) {
        return day * 1728000;
    }

    public static boolean atInterval(Entity entity, int tick) {
        return atInterval(entity.tickCount, tick);
    }

    public static boolean atInterval(Level level, int tick) {
        return atInterval(worldTicks(level), tick);
    }

    public static boolean atInterval(long ticksExisted, int tick) {
        return testInterval(ticksExisted, tick, interval -> {
            return interval.longValue() == 0;
        });
    }

    public static boolean inIntervalBefore(long ticksExisted, int tick, int intervalStart) {
        return testInterval(ticksExisted, tick, interval -> {
            return interval.longValue() < ((long) intervalStart);
        });
    }

    public static boolean inIntervalAfter(long ticksExisted, int tick, int intervalStart) {
        return testInterval(ticksExisted, tick, interval -> {
            return interval.longValue() > ((long) intervalStart);
        });
    }

    public static boolean testInterval(long ticksExisted, int tick, Predicate<Long> intervalPredic) {
        return ticksExisted > 0 && intervalPredic.test(Long.valueOf(ticksExisted % ((long) tick)));
    }

    public static long minuteElapsed(Level level, long oldTime) {
        return minuteElapsed(worldTicks(level), oldTime);
    }

    public static long minuteElapsed(long nowTime, long oldTime) {
        return (nowTime - oldTime) / 1200;
    }

    public static boolean isMinuteElapsed(Level level, long oldTime, int minute) {
        return isMinuteElapsed(worldTicks(level), oldTime, minute);
    }

    public static boolean isMinuteElapsed(long nowTime, long oldTime, int minute) {
        return nowTime - oldTime >= ((long) tickFromMinute(minute));
    }

    public static String getTimeString(int cd) {
        return getTimeString(cd, i -> {
            return ":";
        }, false);
    }

    public static String getTimeStringWithUnit(int cd) {
        return getTimeString(cd, i -> {
            return UNITY[i.intValue()];
        }, true);
    }

    private static String getTimeString(int cd, Function<Integer, String> separator, boolean separatorAtEnd) {
        int[] timeArray = getTimeArray(cd);
        StringBuilder builder = new StringBuilder();
        int start = IntStream.range(0, timeArray.length).filter(i -> {
            return timeArray[i] > 0;
        }).findFirst().orElse(timeArray.length - 1);
        IntStream.range(start, timeArray.length - 1).forEach(unit -> {
            builder.append(String.format(Locale.US, "%02d", Integer.valueOf(timeArray[unit])));
            builder.append((String) separator.apply(Integer.valueOf(unit)));
        });
        builder.append(String.format(Locale.US, "%02d", Integer.valueOf(timeArray[timeArray.length - 1])));
        if (separatorAtEnd) {
            builder.append(separator.apply(Integer.valueOf(timeArray.length - 1)));
        }
        return builder.toString();
    }

    private static int[] getTimeArray(int cd) {
        int[] timeArray = {0, 0, 0, 0};
        if (cd >= 1728000) {
            timeArray[0] = cd / 1728000;
            cd -= timeArray[0] * 1728000;
        }
        if (cd >= 72000) {
            timeArray[1] = cd / 72000;
            cd -= timeArray[1] * 72000;
        }
        if (cd >= 1200) {
            timeArray[2] = cd / 1200;
            cd -= timeArray[2] * 1200;
        }
        if (cd >= 20) {
            timeArray[3] = cd / 20;
        }
        return timeArray;
    }

    public static float flicker(int age, int maxAge) {
        return Mth.sin(3.1415927f * (age / maxAge));
    }

    public static float rise(int age, int maxAge) {
        return Mth.sin(1.5707964f * (age / maxAge));
    }

    public static float downfall(int age, int maxAge) {
        return Mth.cos(1.5707964f * (age / maxAge));
    }
}
